import React, { useEffect } from 'react';
import { SafeAreaView } from 'react-native';
import { apiService } from './api/api';
import NetInfo from '@react-native-community/netinfo';

var template_id = '';
var token = '';
var number: string | number = '';
var otpExpireTime = null;
var otp = null;
var otpLength = null;
var isUnicode = null;
var invisible = null;
var userip = null;
var email = null
var extra_param = null

const WIFI = "wifi"

export default function App() {
    return (
        <SafeAreaView />
    )
}

/**
 * Initialize to defaults.
 */
export function setToDefaults() {
    template_id = '';
    token = '';
    number = '';
    otpExpireTime = null;
    otp = null;
    otpLength = null;
    isUnicode = null;
    invisible = null;
    userip = null;
    email = null;
    extra_param = null;
}

/**
 * [Otp expire time]
 * @param expireTime 
 */
export function setOtpExpireInMinute(expireTime) {
    otpExpireTime = expireTime
}

/**
 * [use your OTP code]
 * @param otp 
 */
export function setOtp(pOtp) {
    otp = pOtp
}

/**
 * [custom OTP length]
 * @param optLength */
export function setOtpLength(pOptLength) {
    otpLength = pOptLength
}

/**
 * [use unicode (or other languages)]
 * @param flag */
export function setUnicodeEnable(flag) {
    isUnicode = flag
}

/**
 * [direct verification while connect with mobile network]
 * @param flag 
 */
export function setVerifyWithoutOtp(flag) {
    invisible = flag
}

/**
 * [User IP]
 * @param pUserip */
export function setUserIp(pUserip) {
    userip = pUserip
}

/**
 * [Email ID on which you want to send OTP]
 * @param pEmail */
export function setEmail(pEmail) {
    email = pEmail
}

/**
 * [Here you can pass the variables created in the SendOTP template.]
 * @param extra_param */
export function setExtraParams(extra_param) {
    extra_param = extra_param
}

/**
*
* @param pTemplate_id
* @param pNumber
* @param pToken
* @returns
*/
export async function generateOTP(pTemplate_id: string, pNumber: string | number, pToken: string) {
    let mobileData = true
    let body = {
        otp_expiry: otpExpireTime,
        otp: otp,
        otp_length: otpLength,
        unicode: isUnicode,
        invisible: invisible,
        userip: userip,
        email: email,
        extra_param: extra_param
    }
    if (invisible) {
        await NetInfo.fetch().then(async (state) => {
            if (state?.type == WIFI) {
                mobileData = await false
            }
        });
    }
    console.log('Mobile data status ', mobileData, body)
    if (mobileData) {
        try {
            template_id = pTemplate_id;
            number = pNumber;
            token = pToken
            const response = await apiService.generateOTP(template_id, number, token, body)
            console.log("Generate otp response", response)
            return response
        } catch (err) {
            console.log("Error in generate otp", err)
        }
    }
}

/**
 *
 * @param otp
 * @returns
 */
export async function verifyOTP(otp: string | number) {
    try {
        let body = {
            otp_expiry: otpExpireTime
        }
        const response = await apiService.verifyOTP(otp, number, token, body)
        console.log("Verify otp response", response)
        return response
    } catch (err) {
        console.log("Error in verify otp", err)
    }
}

/**
 *
 * @param type
 * @returns
 */
export async function resendOTP(type: string = 'voice') {
    try {
        const response = await apiService.resendOTP(number, token, type)
        console.log("Resend otp response", response)
        return response
    } catch (err) {
        console.log("Error in resend otp", err)
    }
}

